@@ -44,6 +44,7 @@
 #include <gtk/gtkcombobox.h>
 #include <glib/gstdio.h>
 #include "girl.h"
+#include "girl-player-frontend.h"
 #include "girl-gui.h"
 #include "girl-program.h"
 #include "girl-station.h"
@@ -67,10 +68,10 @@ GnomeUIInfo toolbar[] = {
 	GNOMEUIINFO_ITEM_STOCK(N_("Record"), N_("Record selected radio station"),
 			       on_record_button_clicked,
 			       GTK_STOCK_MEDIA_RECORD),
+#endif /* HAVE_GIRL_RECORD */	
 	GNOMEUIINFO_ITEM_STOCK(N_("Stop"), N_("Stop recording selected radio station"),
 			       on_stop_button_clicked,
 			       GTK_STOCK_MEDIA_STOP),
-#endif /* HAVE_GIRL_RECORD */
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_ITEM_STOCK(N_("Previous"),
 			       N_("Go back to the previous radio station"),
@@ -514,6 +515,8 @@ on_search_matches(GtkEntryCompletion *widget,
 			girl->selected_station_location,
 			girl->selected_station_uri);
 
+	girl_player_frontend_stop (girl->player_window, NULL);
+
 	girl_helper_run(girl->selected_station_uri,
 			girl->selected_station_name,
 			GIRL_STREAM_SHOUTCAST,
